<?php
namespace BancoTalentos\Controllers;

use BancoTalentos\Services\VagasService;
use Zeedhi\Framework\DTO\{ Request, Response };
use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DTO\Response\{ Error, Message };
use Ems\Util\ExpectedException;

class VagasController {
    /** @param VagasService */
    protected $vagasService;

    public function __construct(
        VagasService $vagasService
    ) {
        $this->vagasService = $vagasService;
    }

    public function getVagas(
        Request\Filter $request,
        Response $response
    ) {
        try {
            $row = $request->getParameters();
            $nrProcesso = $row['NRPROCESSO'] ?? null;

            $vagas = $this->vagasService->getVagas($nrProcesso);

            $response->addDataSet(new DataSet('data', $vagas));
        } catch (ExpectedException $e) {
            $response->addMessage(new Message($e->getMessage(), Message::TYPE_ERROR));
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode(), $e->getTrace()));
        }
    }

    public function toggleVagaFavorita(
        Request\Row $request,
        Response $response
    ) {
        try {
            $row = $request->getRow();
            $nrOrgProcesso = (int) $row['NRORGPROCESSO'];
            $nrProcesso = (int) $row['NRPROCESSO'];

            $fav = $this->vagasService->toggleVagaFavorita(
                $nrOrgProcesso, $nrProcesso
            );

            $dataSet = [
                'fav' => $fav,
            ];

            $response->addDataSet(new DataSet('data', $dataSet));
        } catch (ExpectedException $e) {
            $response->addMessage(new Message($e->getMessage(), Message::TYPE_ERROR));
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode(), $e->getTrace()));
        }
    }

    public function candidatarVaga(
        Request\Row $request,
        Response $response
    ) {
        try {
            $row = $request->getRow()->getArrayCopy();

            $this->vagasService->candidatarVaga($row);

            $response->addDataSet(new DataSet('data', []));
        } catch (ExpectedException $e) {
            $response->addMessage(new Message($e->getMessage(), Message::TYPE_ERROR));
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode(), $e->getTrace()));
        }
    }

    public function enviarIndicacao(
        Request\Row $request,
        Response $response
    ) {
        try {
            $row = $request->getRow();
            $nrProcesso = (int) $row['NRPROCESSO'];
            $email = (string) $row['DSEMAILOPER'];

            $this->vagasService->enviarIndicacao($nrProcesso, $email);

            $response->addDataSet(new DataSet('data', []));
        } catch (ExpectedException $e) {
            $response->addMessage(new Message($e->getMessage(), Message::TYPE_ERROR));
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode(), $e->getTrace()));
        }
    }
}