<?php


namespace BancoTalentos\Services;

use Zeedhi\Framework\Controller\Crud;
use Zeedhi\Framework\DataSource\Manager;
use Zeedhi\Framework\DataSource\ParameterBag;
use Zeedhi\Framework\DataSource\FilterCriteria;
use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DTO\Request\Row;
use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DTO\Request;
use Geral\Util\DateUtil;
use Zeedhi\Framework\DTO\Response\Notification;
use BancoTalentos\Util\Mail\Mail;

class EnviarEmailService {

    const FOOTERCONTENT = 'Tem alguma dúvida? Quer nos dar sugestões? <b>Entre em contato conosco.</b>';


    public function __construct (Mail $mail){
        $this->mail = $mail;
    }

    private function getTemplate($title, $dsemailoper, $nmoperador, $headerContent, $content, $footerContent, $footerTemplate = null, $nmestruturam, $nrorg){
        if($footerContent === null){
            $footerContent = self::FOOTERCONTENT;
        }

        $logo_organizacao = $this->getUrlLogoCliente($nmestruturam, $nrorg);
        $logo_bottom = 'https://frequencia.pebbian.com/images/pebbian_logotipo.png';

        $template = <<<HTML
                    <!DOCTYPE html PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN" "http://www.w3.org/TR/html4/loose.dtd">
                    <html>
                    <head>
                        <title>$title</title>
                    </head>
                    <body style="text-align: center; padding-top: 2%; padding-left: 2%; background-color: #FFF/*rgb(118, 192, 179)*/; margin: 0px; height: auto;">
                        <div style="width:672px; height:330px; box-shadow: 10px 10px 5px #78887d;">
                            <table cellpadding="0" cellspacing="0" style="width: 672px; height: 300px; margin: 0 auto;">
                                <tr style="background-color: #FFF">
                                    <td height="20">
                                        &nbsp;
                                    </td>
                                </tr>
                                <tr style="background-color: #FFF;">
                                    <td style="text-align: center;">
                                        <img width="174" height="56" src="$logo_organizacao" />
                                    </td>
                                </tr>
                                <!--<tr style="background-color: #FFF">
                                    <td height="35">
                                        &nbsp;
                                    </td>
                                </tr>-->
                                <tr style="background-color: #FFF; text-align: left; font: normal 14px Arial, Tahoma, sans-serif; color: #333;">
                                    <td>
                                        <table cellpadding="0" cellspacing="0">
                                            <tr>
                                                <td width="24"></td>
                                                <td height="193">
                                                    <h1 style="font-size: 30px; margin: 0 0 15px 0; /*color: #76c0b3;*/"> $headerContent </h1>
                                                    <p style="margin: 0; padding: 0 0 12px 0; line-height: 17px; text-align: justify;">
                                                        $content
                                                    </p>
                                                </td>
                                                <td width="24"></td>
                                            </tr>
                                        </table>
                                    </td>
                                </tr>
                                <!--<tr style="background-color: #FFF">
                                    <td>
                                        &nbsp;
                                    </td>
                                </tr>
                                <tr style="background-color: #1b9772; color: #FFF; font: normal 13px Arial, Tahoma, sans-serif;">
                                    <td height="17">
                                        &nbsp;
                                    </td>
                                </tr>
                                <tr style="background-color: #1b9772; color: #FFF; font: normal 13px Arial, Tahoma, sans-serif;">
                                    <td align="center">
                                        $footerContent
                                    </td>
                                </tr>
                                <tr style="background-color: #1b9772; color: #FFF; font: normal 13px Arial, Tahoma, sans-serif;">
                                    <td height="10">
                                        &nbsp;
                                    </td>
                                </tr>-->
                                <tr>
                                    <td>
                                        <table cellpadding="0" cellspacing="0">
                                            <tr style="font: normal 14px Arial, Tahoma, sans-serif; text-align: left;">
                                                <!--<td style="padding-right: 30px; padding-top: 10px; padding-left: 30px;">
                                                    <img height="40" src="$logo_bottom" />
                                                </td>-->
                                                <td valign="center" style="padding-left: 40px;">
                                                    $footerTemplate
                                                </td>
                                            </tr>
                                        </table>
                                    </td>
                                </tr>
                            </table>
                        </div>
                    </body>
                    </html>
HTML;
        return $template;

    }

    public function enviarIndicacao (array $row) {
        $title = 'Alerta de Vagas';
        $subject = 'Alerta de Vagas';
        $content = 'Você acaba de ser indicado para vaga <b>'.$row['NMPROCESSO'].'</b> da empresa '.$row['NMESTRUTURAH'].'.<br><br>'.'Acesse o <a href="http://talentos.pebbian.com" target="_blank">Portal de Talentos</a> para obter mais detalhes sobre esta vaga.';
        $headerContent = '<b>Olá,</b>'; //.' '.$row['NMOPERADOR'];
        $footerContent = null;
        $footerTemplate = 'Você está recebendo este e-mail por ter sido indicado por <b>'.$row['NMOPERADOR'].'</b>.';
        $nmfrom = 'RH Teknisa';

        $this->enviarEmailAlerta($title, $row['DSEMAILOPER'], $row['NMOPERADOR'], $row['NMESTRUTURAH'], $subject, $content, $headerContent, $footerContent, $footerTemplate, $nmfrom, $row['NRORGPROCESSO']);

    }

    public function enviarNovaSenha($email, $nmoperador, $novasenha, $nmestruturam, $nrorg) {
        $title = "Recuperação de Senha";
        $subject = "Recuperação de Senha";
        $headerContent = "<b>Olá, ". $nmoperador ."</b>";
        $content = "Sua nova senha é: <b>".$novasenha."</b> <br><br>
                   Acesse nosso sistema informando sua nova senha, após o acesso altere a mesma.";
        $footerContent = null;
        $footerTemplate = "Você está recebendo esse email por ter solicitado uma nova senha em nosso sistema.";
        $nmfrom = null;
        $nmestruturam = "teknisa";

        return $this->enviarEmailAlerta($title, $email, $nmoperador, $nmestruturam, $subject, $content, $headerContent, $footerContent, $footerTemplate, $nmfrom, $nrorg);
    }

    public function enviarEmailAlerta($title, $email, $nmoperador, $nmestruturam, $subject, $content, $headerContent, $footerContent, $footerTemplate, $nmfrom, $nrorg){

        try {

            $this->dsemailoper = $email;
            $content = self::getTemplate($title, $this->dsemailoper, $nmoperador, $headerContent, $content, $footerContent, $footerTemplate, $nmestruturam, $nrorg);
            $return = $this->mail->newEmail($this->dsemailoper, $content, $subject, $this->dsemailoper, $nmfrom);

            return $return;

        }
        catch(\Exception $e){
            throw new \Exception($e->getMessage(), $e->getCode());
        }

    }

    public function getUrlLogoCliente($nmestruturam, $nrorg) {
        $nmestruturam = strtolower(current(str_word_count($nmestruturam, 2)));
        //$nmestruturam = "tecfood";
        $logo_organizacao = "https://hcmmobile.pebbian.com/images/". $nrorg ."/". $nmestruturam ."-logotipo.png";

        return $logo_organizacao;
    }
    
}