<?php

namespace BancoTalentos\Util;

/**
 *  Abstract Service
 * 
 *  Define rotinas comuns as entidades 'Service'
 * 
 */

abstract class Service {
    private const ENTITY_PERSIST_INSTANCE_NAME = 'doctrineEntityUtil';

    /**
     *  Rotina que identificara o repositorio correto para cada entidade.
     * 
     */
    public abstract function getRepository();

    /**
     *  Rotina responsavel por obter a entidade capaz de realizar as operacoes sobre as entidades.
     * 
     *  @return EntityPersistInstance
     */
    public function getEntityPersistInstance(): EntityPersistInstance {
        return Util::getInstance(self::ENTITY_PERSIST_INSTANCE_NAME);
    }

    /**
     *  Rotina responsavel por incluir novas entidades. Definida em EntityPersistInstance
     * 
     *  @param  array   $row
     *  @param  array   $config
     */
    public function set(
        array $row,
        array $config
    ) {
        return $this->getEntityPersistInstance()->setNewEntity(
            $this->getRepository(),
            $row,
            $config['SET_DEFAULT_FIELDS']   ?? null,
            $config['PERSIST']              ?? null,
            $config['FLUSH']                ?? null,
            $config['PENDING']              ?? null
        );
    }
}