<?php

namespace BancoTalentos\Util;

use Zeedhi\Framework\DependencyInjection\InstanceManager;

class Util {

    public const DEFAULT_ORG = '0';

    public const ESPECIAL_CHARACTERS_TRANSLATION = [
        "ª" => "", "º" => "", "à" => "a","á" => "a","ã" => "a","â" => "a","é" => "e","ê" => "e","ì" => "i","í" => "i",
        "ó" => "o", "õ" => "o","ô" => "o","ú" => "u","ü" => "u","ç" => "c","À" => "A","Á" => "A","Ã" => "A","Â" => "A",
        "É" => "E","Ê" => "E","Í" => "I","Ó" => "O","Õ" => "O","Ô" => "O","Ù" => "U","Ú" => "U","Ü" => "U","." => ""
    ];

    public static function getInstance(string $instanceName) {
        $instanceManager = InstanceManager::getInstance();
        return $instanceManager->getService($instanceName);
    }

    public static function getEntityManager() {
        return self::getInstance('entityManager');
    }

    public static function getParamters() {
        return self::getInstance('BTParameters');
    }

    public static function getDoctrineEntityUtil() {
        return self::getInstance('doctrineEntityUtil');
    }
    
    /**
     *  Rotina que verifica se todos os campos informados estão preenchidos no array informado
     * 
     *  @param  Array   $row
     *  @param  Array   $atLeastOneFields
     *  @param  bool    $throwError         = true
     * 
     *  @return bool
     * 
     *  @throws \Exception
     * 
     */
    public static function checkRequiredFields(Array $row, Array $requiredFields, bool $throwError = true) {
        $fieldsNotFilled = [];
        foreach ($requiredFields as $field) {
            if (!isset($row[$field]) || empty($row[$field])) {
                $fieldsNotFilled[] = $field;
            }
        }
        
        $requiredFieldsNotFilled = count($fieldsNotFilled) > 0;
        if ($requiredFieldsNotFilled && $throwError) {
            throw new \Exception('Os seguintes campos obrigatórios não foram preenchidos: ' . implode(', ', $fieldsNotFilled));
        }
        
        return ['isValid' => $requiredFieldsNotFilled, 'fields' => $fieldsNotFilled];
    }

    public static function sanitizeCPF(string $cpf) {
        return strtr($cpf, array('.' => '', '-' => ''));
    }

    public static function getNextCdoperadorAvailable() {
        $updateNovoCodigoUpdate =
            "SELECT MAX(CDOPERADOR)+1 AS DATA FROM OPERADOR WHERE REGEXP_LIKE(CDOPERADOR, '^[[:digit:]]+$')";
        
        $query = self::getEntityManager()->getConnection()->prepare($updateNovoCodigoUpdate);
        $query->execute();
        $data = $query->fetch();

        return $data['DATA'] ?? null;
    }

    public static function decompoeNomeCompleto(string $nmpessoa) {
        $arrayNmpessoa = explode(' ', $nmpessoa);
        $nomeMeio      = '';

        $primeiroNome = $arrayNmpessoa[0];
        for ($i = 1; $i < count($arrayNmpessoa) - 1; $i++) {
            $nomeMeio .= ' ' . $arrayNmpessoa[$i];
            $nomeMeio = trim($nomeMeio);
        }
        $ultimoNome = $arrayNmpessoa[count($arrayNmpessoa) - 1];
        $nomeMeio   = ($nomeMeio) ? : $ultimoNome;
        return array($primeiroNome, $nomeMeio, $ultimoNome);
    }

    public static function removeCaracteresEspeciais(string $str) {
        return strtr($str, self::ESPECIAL_CHARACTERS_TRANSLATION);
    }
}
